@@ -1,5 +1,6 @@
 from __future__ import unicode_literals
 
+import django
 from django import forms
 from django.conf import settings
 from guardian.compat import url
@@ -14,7 +15,8 @@ from django.utils.translation import ugettext, ugettext_lazy as _
 from guardian.compat import OrderedDict, get_user_model, get_model_name
 from guardian.forms import UserObjectPermissionsForm
 from guardian.forms import GroupObjectPermissionsForm
-from guardian.shortcuts import get_perms
+from guardian.shortcuts import get_user_perms
+from guardian.shortcuts import get_group_perms
 from guardian.shortcuts import get_users_with_perms
 from guardian.shortcuts import get_groups_with_perms
 from guardian.shortcuts import get_perms_for_model
@@ -27,6 +29,7 @@ class AdminUserObjectPermissionsForm(UserObjectPermissionsForm):
     ``get_obj_perms_field_widget`` method so it return
     ``django.contrib.admin.widgets.FilteredSelectMultiple`` widget.
     """
+
     def get_obj_perms_field_widget(self):
         return FilteredSelectMultiple(_("Permissions"), False)
 
@@ -37,6 +40,7 @@ class AdminGroupObjectPermissionsForm(GroupObjectPermissionsForm):
     ``get_obj_perms_field_widget`` method so it return
     ``django.contrib.admin.widgets.FilteredSelectMultiple`` widget.
     """
+
     def get_obj_perms_field_widget(self):
         return FilteredSelectMultiple(_("Permissions"), False)
 
@@ -98,25 +102,33 @@ class GuardedModelAdminMixin(object):
         if self.include_object_permissions_urls:
             info = self.model._meta.app_label, get_model_name(self.model)
             myurls = [
-                              url(r'^(?P<object_pk>.+)/permissions/$',
-                                  view=self.admin_site.admin_view(self.obj_perms_manage_view),
-                                  name='%s_%s_permissions' % info),
-                              url(r'^(?P<object_pk>.+)/permissions/user-manage/(?P<user_id>\-?\d+)/$',
-                                  view=self.admin_site.admin_view(self.obj_perms_manage_user_view),
-                                  name='%s_%s_permissions_manage_user' % info),
-                              url(r'^(?P<object_pk>.+)/permissions/group-manage/(?P<group_id>\-?\d+)/$',
-                                  view=self.admin_site.admin_view(self.obj_perms_manage_group_view),
-                                  name='%s_%s_permissions_manage_group' % info),
-                              ]
+                url(r'^(?P<object_pk>.+)/permissions/$',
+                    view=self.admin_site.admin_view(
+                        self.obj_perms_manage_view),
+                    name='%s_%s_permissions' % info),
+                url(r'^(?P<object_pk>.+)/permissions/user-manage/(?P<user_id>\-?\d+)/$',
+                    view=self.admin_site.admin_view(
+                        self.obj_perms_manage_user_view),
+                    name='%s_%s_permissions_manage_user' % info),
+                url(r'^(?P<object_pk>.+)/permissions/group-manage/(?P<group_id>\-?\d+)/$',
+                    view=self.admin_site.admin_view(
+                        self.obj_perms_manage_group_view),
+                    name='%s_%s_permissions_manage_group' % info),
+            ]
             urls = myurls + urls
         return urls
 
     def get_obj_perms_base_context(self, request, obj):
         """
         Returns context dictionary with common admin and object permissions
-        related content.
+        related content. It uses AdminSite.each_context (available in Django >= 1.8,
+        making sure all required template vars are in the context.
         """
-        context = {
+        if django.VERSION >= (1, 8):
+            context = self.admin_site.each_context(request)
+        else:
+            context = {}
+        context.update( {
             'adminform': {'model_admin': self},
             'media': self.media,
             'object': obj,
@@ -126,7 +138,7 @@ class GuardedModelAdminMixin(object):
             'has_change_permission': self.has_change_permission(request, obj),
             'model_perms': get_perms_for_model(obj),
             'title': _("Object permissions"),
-        }
+        })
         return context
 
     def obj_perms_manage_view(self, request, object_pk):
@@ -147,11 +159,14 @@ class GuardedModelAdminMixin(object):
         except ImportError:
             # django < 1.7
             from django.contrib.admin.util import unquote
-        obj = get_object_or_404(self.get_queryset(request), pk=unquote(object_pk))
+        obj = get_object_or_404(self.get_queryset(
+            request), pk=unquote(object_pk))
         users_perms = OrderedDict(
             sorted(
-                get_users_with_perms(obj, attach_perms=True, with_group_users=False).items(),
-                key=lambda user: getattr(user[0], get_user_model().USERNAME_FIELD)
+                get_users_with_perms(obj, attach_perms=True,
+                                     with_group_users=False).items(),
+                key=lambda user: getattr(
+                    user[0], get_user_model().USERNAME_FIELD)
             )
         )
 
@@ -251,7 +266,7 @@ class GuardedModelAdminMixin(object):
 
         context = self.get_obj_perms_base_context(request, obj)
         context['user_obj'] = user
-        context['user_perms'] = get_perms(user, obj)
+        context['user_perms'] = get_user_perms(user, obj)
         context['form'] = form
 
         request.current_app = self.admin_site.name
@@ -309,7 +324,7 @@ class GuardedModelAdminMixin(object):
 
         context = self.get_obj_perms_base_context(request, obj)
         context['group_obj'] = group
-        context['group_perms'] = get_perms(group, obj)
+        context['group_perms'] = get_group_perms(group, obj)
         context['form'] = form
 
         request.current_app = self.admin_site.name
@@ -421,8 +436,10 @@ class GuardedModelAdmin(GuardedModelAdminMixin, admin.ModelAdmin):
 class UserManage(forms.Form):
     user = forms.CharField(label=_("User identification"),
                            max_length=200,
-                           error_messages={'does_not_exist': _("This user does not exist")},
-                           help_text=_('Enter a value compatible with User.USERNAME_FIELD')
+                           error_messages={'does_not_exist': _(
+                               "This user does not exist")},
+                           help_text=_(
+                               'Enter a value compatible with User.USERNAME_FIELD')
                            )
 
     def clean_user(self):
@@ -445,7 +462,7 @@ class UserManage(forms.Form):
 
 class GroupManage(forms.Form):
     group = forms.CharField(max_length=80, error_messages={'does_not_exist':
-                            _("This group does not exist")})
+                                                           _("This group does not exist")})
 
     def clean_group(self):
         """
