@@ -46,7 +46,7 @@ class LoginRequiredMixin(object):
 
     def dispatch(self, request, *args, **kwargs):
         return login_required(redirect_field_name=self.redirect_field_name,
-            login_url=self.login_url)(
+                              login_url=self.login_url)(
             super(LoginRequiredMixin, self).dispatch
         )(request, *args, **kwargs)
 
@@ -59,8 +59,8 @@ class PermissionRequiredMixin(object):
     If a `get_object()` method is defined either manually or by including
     another mixin (for example ``SingleObjectMixin``) or ``self.object`` is
     defined then the permission will be tested against that specific instance,
-    alternatively you can specify `get_permission_object()` method if ``self.object`` 
-    or `get_object()` does not return the object against you want to test permission 
+    alternatively you can specify `get_permission_object()` method if ``self.object``
+    or `get_object()` does not return the object against you want to test permission
 
     .. note:
        Testing of a permission against a specific object instance requires an
@@ -121,11 +121,11 @@ class PermissionRequiredMixin(object):
 
     ``PermissionRequiredMixin.permission_object``
          *Default*: ``None``, object against which test the permission; if None fallback
-         to ``self.get_permission_object()`` which return ``self.get_object()`` 
+         to ``self.get_permission_object()`` which return ``self.get_object()``
          or ``self.object`` by default.
 
     """
-    ### default class view settings
+    # default class view settings
     login_url = settings.LOGIN_URL
     permission_required = None
     redirect_field_name = REDIRECT_FIELD_NAME
@@ -133,6 +133,7 @@ class PermissionRequiredMixin(object):
     raise_exception = False
     accept_global_perms = False
     permission_object = None
+
     def get_required_permissions(self, request=None):
         """
         Returns list of permissions in format *<app_label>.<codename>* that
@@ -147,17 +148,17 @@ class PermissionRequiredMixin(object):
             perms = [p for p in self.permission_required]
         else:
             raise ImproperlyConfigured("'PermissionRequiredMixin' requires "
-                "'permission_required' attribute to be set to "
-                "'<app_label>.<permission codename>' but is set to '%s' instead"
-                % self.permission_required)
+                                       "'permission_required' attribute to be set to "
+                                       "'<app_label>.<permission codename>' but is set to '%s' instead"
+                                       % self.permission_required)
         return perms
-    
+
     def get_permission_object(self):
         if self.permission_object:
             return self.permission_object
         return (hasattr(self, 'get_object') and self.get_object()
                 or getattr(self, 'object', None))
-                
+
     def check_permissions(self, request):
         """
         Checks if *request.user* has all permissions returned by
@@ -167,15 +168,15 @@ class PermissionRequiredMixin(object):
         """
         obj = self.get_permission_object()
 
-
         forbidden = get_403_or_None(request,
-            perms=self.get_required_permissions(request),
-            obj=obj,
-            login_url=self.login_url,
-            redirect_field_name=self.redirect_field_name,
-            return_403=self.return_403,
-            accept_global_perms=self.accept_global_perms
-        )
+                                    perms=self.get_required_permissions(
+                                        request),
+                                    obj=obj,
+                                    login_url=self.login_url,
+                                    redirect_field_name=self.redirect_field_name,
+                                    return_403=self.return_403,
+                                    accept_global_perms=self.accept_global_perms
+                                    )
         if forbidden:
             self.on_permission_check_fail(request, forbidden, obj=obj)
         if forbidden and self.raise_exception:
@@ -201,10 +202,11 @@ class PermissionRequiredMixin(object):
         if response:
             return response
         return super(PermissionRequiredMixin, self).dispatch(request, *args,
-            **kwargs)
+                                                             **kwargs)
 
 
 class GuardianUserMixin(object):
+
     @staticmethod
     def get_anonymous():
         return get_anonymous_user()
