@@ -22,6 +22,7 @@ from guardian.utils import get_identity
 from guardian.utils import get_user_obj_perms_model
 import warnings
 
+
 def assign_perm(perm, user_or_group, obj=None):
     """
     Assigns permission to user/group and object pair.
@@ -76,9 +77,9 @@ def assign_perm(perm, user_or_group, obj=None):
             app_label, codename = perm.split('.', 1)
         except ValueError:
             raise ValueError("For global permissions, first argument must be in"
-                " format: 'app_label.codename' (is %r)" % perm)
+                             " format: 'app_label.codename' (is %r)" % perm)
         perm = Permission.objects.get(content_type__app_label=app_label,
-            codename=codename)
+                                      codename=codename)
         if user:
             user.user_permissions.add(perm)
             return perm
@@ -93,11 +94,13 @@ def assign_perm(perm, user_or_group, obj=None):
         model = get_group_obj_perms_model(obj)
         return model.objects.assign_perm(perm, group, obj)
 
+
 def assign(perm, user_or_group, obj=None):
     """ Depreciated function name left in for compatibility"""
     warnings.warn("Shortcut function 'assign' is being renamed to 'assign_perm'. Update your code accordingly as old name will be depreciated in 2.0 version.", DeprecationWarning)
     return assign_perm(perm, user_or_group, obj)
 
+
 def remove_perm(perm, user_or_group=None, obj=None):
     """
     Removes permission from user/group and object pair.
@@ -120,9 +123,9 @@ def remove_perm(perm, user_or_group=None, obj=None):
             app_label, codename = perm.split('.', 1)
         except ValueError:
             raise ValueError("For global permissions, first argument must be in"
-                " format: 'app_label.codename' (is %r)" % perm)
+                             " format: 'app_label.codename' (is %r)" % perm)
         perm = Permission.objects.get(content_type__app_label=app_label,
-            codename=codename)
+                                      codename=codename)
         if user:
             user.user_permissions.remove(perm)
             return
@@ -137,6 +140,7 @@ def remove_perm(perm, user_or_group=None, obj=None):
         model = get_group_obj_perms_model(obj)
         model.objects.remove_perm(perm, group, obj)
 
+
 def get_perms(user_or_group, obj):
     """
     Returns permissions for given user/group and object pair, as list of
@@ -145,6 +149,25 @@ def get_perms(user_or_group, obj):
     check = ObjectPermissionChecker(user_or_group)
     return check.get_perms(obj)
 
+
+def get_user_perms(user, obj):
+    """
+    Returns permissions for given user and object pair, as list of
+    strings, only those assigned directly for the user.
+    """
+    check = ObjectPermissionChecker(user)
+    return check.get_user_perms(obj)
+
+
+def get_group_perms(user_or_group, obj):
+    """
+    Returns permissions for given user/group and object pair, as list of
+    strings. It returns only those which are inferred through groups.
+    """
+    check = ObjectPermissionChecker(user_or_group)
+    return check.get_group_perms(obj)
+
+
 def get_perms_for_model(cls):
     """
     Returns queryset of all Permission objects for the given class. It is
@@ -158,8 +181,9 @@ def get_perms_for_model(cls):
     ctype = ContentType.objects.get_for_model(model)
     return Permission.objects.filter(content_type=ctype)
 
+
 def get_users_with_perms(obj, attach_perms=False, with_superusers=False,
-        with_group_users=True):
+                         with_group_users=True):
     """
     Returns queryset of all ``User`` objects with *any* object permissions for
     the given ``obj``.
@@ -228,10 +252,16 @@ def get_users_with_perms(obj, attach_perms=False, with_superusers=False,
         # TODO: Do not hit db for each user!
         users = {}
         for user in get_users_with_perms(obj,
-                with_group_users=with_group_users):
-            users[user] = sorted(get_perms(user, obj))
+                                         with_group_users=with_group_users,
+                                         with_superusers=with_superusers):
+            # TODO: Support the case of set with_group_users but not with_superusers.
+            if with_group_users or with_superusers:
+                users[user] = sorted(get_perms(user, obj))
+            else:
+                users[user] = sorted(get_user_perms(user, obj))
         return users
 
+
 def get_groups_with_perms(obj, attach_perms=False):
     """
     Returns queryset of all ``Group`` objects with *any* object permissions for
@@ -279,13 +309,13 @@ def get_groups_with_perms(obj, attach_perms=False):
         # TODO: Do not hit db for each group!
         groups = {}
         for group in get_groups_with_perms(obj):
-            if not group in groups:
-                groups[group] = sorted(get_perms(group, obj))
+            if group not in groups:
+                groups[group] = sorted(get_group_perms(group, obj))
         return groups
 
 
 def get_objects_for_user(user, perms, klass=None, use_groups=True, any_perm=False,
-        with_superuser=True, accept_global_perms=True):
+                         with_superuser=True, accept_global_perms=True):
     """
     Returns queryset of objects for which a given ``user`` has *all*
     permissions present at ``perms``.
@@ -400,7 +430,7 @@ def get_objects_for_user(user, perms, klass=None, use_groups=True, any_perm=Fals
             new_app_label, codename = perm.split('.', 1)
             if app_label is not None and app_label != new_app_label:
                 raise MixedContentTypeError("Given perms must have same app "
-                    "label (%s != %s)" % (app_label, new_app_label))
+                                            "label (%s != %s)" % (app_label, new_app_label))
             else:
                 app_label = new_app_label
         else:
@@ -408,10 +438,10 @@ def get_objects_for_user(user, perms, klass=None, use_groups=True, any_perm=Fals
         codenames.add(codename)
         if app_label is not None:
             new_ctype = ContentType.objects.get(app_label=app_label,
-                permission__codename=codename)
+                                                permission__codename=codename)
             if ctype is not None and ctype != new_ctype:
                 raise MixedContentTypeError("ContentType was once computed "
-                    "to be %s and another one %s" % (ctype, new_ctype))
+                                            "to be %s and another one %s" % (ctype, new_ctype))
             else:
                 ctype = new_ctype
 
@@ -427,7 +457,7 @@ def get_objects_for_user(user, perms, klass=None, use_groups=True, any_perm=Fals
         queryset = _get_queryset(klass)
         if ctype.model_class() != queryset.model:
             raise MixedContentTypeError("Content type for given perms and "
-                "klass differs")
+                                        "klass differs")
 
     # At this point, we should have both ctype and queryset and they should
     # match which means: ctype.model_class() == queryset.model
@@ -452,7 +482,7 @@ def get_objects_for_user(user, perms, klass=None, use_groups=True, any_perm=Fals
                 global_perms.add(code)
         for code in global_perms:
             codenames.remove(code)
-        ## prerequisite: there must be elements in global_perms otherwise just follow the procedure for
+        # prerequisite: there must be elements in global_perms otherwise just follow the procedure for
         # object based permissions only AND
         # 1. codenames is empty, which means that permissions are ONLY set globally, therefore return the full queryset.
         # OR
@@ -469,18 +499,21 @@ def get_objects_for_user(user, perms, klass=None, use_groups=True, any_perm=Fals
         elif len(global_perms) > 0 and (len(codenames) > 0):
             has_global_perms = True
 
-
-    # Now we should extract list of pk values for which we would filter queryset
+    # Now we should extract list of pk values for which we would filter
+    # queryset
     user_model = get_user_obj_perms_model(queryset.model)
     user_obj_perms_queryset = (user_model.objects
-        .filter(user=user)
-        .filter(permission__content_type=ctype))
+                               .filter(user=user)
+                               .filter(permission__content_type=ctype))
     if len(codenames):
-        user_obj_perms_queryset = user_obj_perms_queryset.filter(permission__codename__in=codenames)
+        user_obj_perms_queryset = user_obj_perms_queryset.filter(
+            permission__codename__in=codenames)
+    direct_fields = ['content_object__pk', 'permission__codename']
+    generic_fields = ['object_pk', 'permission__codename']
     if user_model.objects.is_generic():
-        fields = ['object_pk', 'permission__codename']
+        user_fields = generic_fields
     else:
-        fields = ['content_object__pk', 'permission__codename']
+        user_fields = direct_fields
 
     if use_groups:
         group_model = get_group_obj_perms_model(queryset.model)
@@ -494,14 +527,15 @@ def get_objects_for_user(user, perms, klass=None, use_groups=True, any_perm=Fals
             })
         groups_obj_perms_queryset = group_model.objects.filter(**group_filters)
         if group_model.objects.is_generic():
-            fields = ['object_pk', 'permission__codename']
+            group_fields = generic_fields
         else:
-            fields = ['content_object__pk', 'permission__codename']
+            group_fields = direct_fields
         if not any_perm and len(codenames) and not has_global_perms:
-            user_obj_perms = user_obj_perms_queryset.values_list(*fields)
-            groups_obj_perms = groups_obj_perms_queryset.values_list(*fields)
+            user_obj_perms = user_obj_perms_queryset.values_list(*user_fields)
+            groups_obj_perms = groups_obj_perms_queryset.values_list(*group_fields)
             data = list(user_obj_perms) + list(groups_obj_perms)
-            keyfunc = lambda t: t[0] # sorting/grouping by pk (first in result tuple)
+            # sorting/grouping by pk (first in result tuple)
+            keyfunc = lambda t: t[0]
             data = sorted(data, key=keyfunc)
             pk_list = []
             for pk, group in groupby(data, keyfunc):
@@ -512,20 +546,22 @@ def get_objects_for_user(user, perms, klass=None, use_groups=True, any_perm=Fals
             return objects
 
     if not any_perm and len(codenames) > 1:
-        counts = user_obj_perms_queryset.values(fields[0]).annotate(object_pk_count=Count(fields[0]))
-        user_obj_perms_queryset = counts.filter(object_pk_count__gte=len(codenames))
+        counts = user_obj_perms_queryset.values(
+            user_fields[0]).annotate(object_pk_count=Count(user_fields[0]))
+        user_obj_perms_queryset = counts.filter(
+            object_pk_count__gte=len(codenames))
 
-    values = user_obj_perms_queryset.values_list(fields[0], flat=True)
+    values = user_obj_perms_queryset.values_list(user_fields[0], flat=True)
     if user_model.objects.is_generic():
         values = list(values)
-    objects = queryset.filter(pk__in=values)
+    q = Q(pk__in=values)
     if use_groups:
-        values = groups_obj_perms_queryset.values_list(fields[0], flat=True)
+        values = groups_obj_perms_queryset.values_list(group_fields[0], flat=True)
         if group_model.objects.is_generic():
             values = list(values)
-        objects |= queryset.filter(pk__in=values)
+        q |= Q(pk__in=values)
 
-    return objects
+    return queryset.filter(q)
 
 
 def get_objects_for_group(group, perms, klass=None, any_perm=False, accept_global_perms=True):
@@ -597,7 +633,7 @@ def get_objects_for_group(group, perms, klass=None, any_perm=False, accept_globa
             new_app_label, codename = perm.split('.', 1)
             if app_label is not None and app_label != new_app_label:
                 raise MixedContentTypeError("Given perms must have same app "
-                    "label (%s != %s)" % (app_label, new_app_label))
+                                            "label (%s != %s)" % (app_label, new_app_label))
             else:
                 app_label = new_app_label
         else:
@@ -605,26 +641,26 @@ def get_objects_for_group(group, perms, klass=None, any_perm=False, accept_globa
         codenames.add(codename)
         if app_label is not None:
             new_ctype = ContentType.objects.get(app_label=app_label,
-                permission__codename=codename)
+                                                permission__codename=codename)
             if ctype is not None and ctype != new_ctype:
                 raise MixedContentTypeError("ContentType was once computed "
-                    "to be %s and another one %s" % (ctype, new_ctype))
+                                            "to be %s and another one %s" % (ctype, new_ctype))
             else:
                 ctype = new_ctype
 
     # Compute queryset and ctype if still missing
-    if ctype is None and klass is None:
-        raise WrongAppError("Cannot determine content type")
-    elif ctype is None and klass is not None:
+    if ctype is None and klass is not None:
         queryset = _get_queryset(klass)
         ctype = ContentType.objects.get_for_model(queryset.model)
     elif ctype is not None and klass is None:
         queryset = _get_queryset(ctype.model_class())
+    elif klass is None:
+        raise WrongAppError("Cannot determine content type")
     else:
         queryset = _get_queryset(klass)
         if ctype.model_class() != queryset.model:
             raise MixedContentTypeError("Content type for given perms and "
-                "klass differs")
+                                        "klass differs")
 
     # At this point, we should have both ctype and queryset and they should
     # match which means: ctype.model_class() == queryset.model
@@ -641,25 +677,34 @@ def get_objects_for_group(group, perms, klass=None, any_perm=False, accept_globa
         if len(global_perms) > 0 and (len(codenames) == 0 or any_perm):
             return queryset
 
-    # Now we should extract list of pk values for which we would filter queryset
+    # Now we should extract list of pk values for which we would filter
+    # queryset
     group_model = get_group_obj_perms_model(queryset.model)
     groups_obj_perms_queryset = (group_model.objects
-        .filter(group=group)
-        .filter(permission__content_type=ctype)
-        .filter(permission__codename__in=codenames))
+                                 .filter(group=group)
+                                 .filter(permission__content_type=ctype))
+    if len(codenames):
+        groups_obj_perms_queryset = groups_obj_perms_queryset.filter(
+            permission__codename__in=codenames)
     if group_model.objects.is_generic():
         fields = ['object_pk', 'permission__codename']
     else:
         fields = ['content_object__pk', 'permission__codename']
-    groups_obj_perms = groups_obj_perms_queryset.values_list(*fields)
-    data = list(groups_obj_perms)
+    if not any_perm and len(codenames):
+        groups_obj_perms = groups_obj_perms_queryset.values_list(*fields)
+        data = list(groups_obj_perms)
 
-    keyfunc = lambda t: t[0] # sorting/grouping by pk (first in result tuple)
-    data = sorted(data, key=keyfunc)
-    pk_list = []
-    for pk, group in groupby(data, keyfunc):
-        obj_codenames = set((e[1] for e in group))
-        if any_perm or codenames.issubset(obj_codenames):
-            pk_list.append(pk)
-    objects = queryset.filter(pk__in=pk_list)
-    return objects
+        keyfunc = lambda t: t[0]  # sorting/grouping by pk (first in result tuple)
+        data = sorted(data, key=keyfunc)
+        pk_list = []
+        for pk, group in groupby(data, keyfunc):
+            obj_codenames = set((e[1] for e in group))
+            if any_perm or codenames.issubset(obj_codenames):
+                pk_list.append(pk)
+        objects = queryset.filter(pk__in=pk_list)
+        return objects
+
+    values = groups_obj_perms_queryset.values_list(fields[0], flat=True)
+    if group_model.objects.is_generic():
+        values = list(values)
+    return queryset.filter(pk__in=values)
