@@ -23,6 +23,7 @@ from guardian.testapp.models import LogEntryWithGroup as LogEntry
 
 User = get_user_model()
 
+
 class ContentTypeGuardedAdmin(GuardedModelAdmin):
     pass
 
@@ -32,16 +33,18 @@ except admin.sites.NotRegistered:
     pass
 admin.site.register(ContentType, ContentTypeGuardedAdmin)
 
+
 @override_settings(**TEST_SETTINGS)
 class AdminTests(TestCase):
 
     def setUp(self):
         self.admin = User.objects.create_superuser('admin', 'admin@example.com',
-            'admin')
+                                                   'admin')
         self.user = User.objects.create_user('joe', 'joe@example.com', 'joe')
         self.group = Group.objects.create(name='group')
         self.client = Client()
-        self.obj = ContentType.objects.create(model='bar', app_label='fake-for-guardian-tests')
+        self.obj = ContentType.objects.create(
+            model='bar', app_label='fake-for-guardian-tests')
         self.obj_info = self.obj._meta.app_label, get_model_name(self.obj)
 
     def tearDown(self):
@@ -53,14 +56,14 @@ class AdminTests(TestCase):
     def test_view_manage_wrong_obj(self):
         self._login_superuser()
         url = reverse('admin:%s_%s_permissions_manage_user' % self.obj_info,
-                kwargs={'object_pk': -10, 'user_id': self.user.pk})
+                      kwargs={'object_pk': -10, 'user_id': self.user.pk})
         response = self.client.get(url)
         self.assertEqual(response.status_code, 404)
 
     def test_view(self):
         self._login_superuser()
         url = reverse('admin:%s_%s_permissions' % self.obj_info,
-            args=[self.obj.pk])
+                      args=[self.obj.pk])
         response = self.client.get(url)
         self.assertEqual(response.status_code, 200)
         self.assertEqual(response.context['object'], self.obj)
@@ -68,40 +71,40 @@ class AdminTests(TestCase):
     def test_view_manage_wrong_user(self):
         self._login_superuser()
         url = reverse('admin:%s_%s_permissions_manage_user' % self.obj_info,
-            kwargs={'object_pk': self.obj.pk, 'user_id': -10})
+                      kwargs={'object_pk': self.obj.pk, 'user_id': -10})
         response = self.client.get(url)
         self.assertEqual(response.status_code, 404)
 
     def test_view_manage_user_form(self):
         self._login_superuser()
         url = reverse('admin:%s_%s_permissions' % self.obj_info,
-            args=[self.obj.pk])
+                      args=[self.obj.pk])
         data = {'user': self.user.username, 'submit_manage_user': 'submit'}
         response = self.client.post(url, data, follow=True)
         self.assertEqual(len(response.redirect_chain), 1)
         self.assertEqual(response.redirect_chain[0][1], 302)
         redirect_url = reverse('admin:%s_%s_permissions_manage_user' %
-            self.obj_info, kwargs={'object_pk': self.obj.pk,
-                'user_id': self.user.pk})
+                               self.obj_info, kwargs={'object_pk': self.obj.pk,
+                                                      'user_id': self.user.pk})
         self.assertEqual(response.request['PATH_INFO'], redirect_url)
 
     def test_view_manage_negative_user_form(self):
         self._login_superuser()
         url = reverse('admin:%s_%s_permissions' % self.obj_info,
-            args=[self.obj.pk])
+                      args=[self.obj.pk])
         self.user = User.objects.create(username='negative_id_user', pk=-2010)
         data = {'user': self.user.username, 'submit_manage_user': 'submit'}
         response = self.client.post(url, data, follow=True)
         self.assertEqual(len(response.redirect_chain), 1)
         self.assertEqual(response.redirect_chain[0][1], 302)
         redirect_url = reverse('admin:%s_%s_permissions_manage_user' %
-            self.obj_info, args=[self.obj.pk, self.user.pk])
+                               self.obj_info, args=[self.obj.pk, self.user.pk])
         self.assertEqual(response.request['PATH_INFO'], redirect_url)
 
     def test_view_manage_user_form_wrong_user(self):
         self._login_superuser()
         url = reverse('admin:%s_%s_permissions' % self.obj_info,
-            args=[self.obj.pk])
+                      args=[self.obj.pk])
         data = {'user': 'wrong-user', 'submit_manage_user': 'submit'}
         response = self.client.post(url, data, follow=True)
         self.assertEqual(len(response.redirect_chain), 0)
@@ -111,7 +114,7 @@ class AdminTests(TestCase):
     def test_view_manage_user_form_wrong_field(self):
         self._login_superuser()
         url = reverse('admin:%s_%s_permissions' % self.obj_info,
-            args=[self.obj.pk])
+                      args=[self.obj.pk])
         data = {'user': '<xss>', 'submit_manage_user': 'submit'}
         response = self.client.post(url, data, follow=True)
         self.assertEqual(len(response.redirect_chain), 0)
@@ -121,7 +124,7 @@ class AdminTests(TestCase):
     def test_view_manage_user_form_empty_user(self):
         self._login_superuser()
         url = reverse('admin:%s_%s_permissions' % self.obj_info,
-            args=[self.obj.pk])
+                      args=[self.obj.pk])
         data = {'user': '', 'submit_manage_user': 'submit'}
         response = self.client.post(url, data, follow=True)
         self.assertEqual(len(response.redirect_chain), 0)
@@ -131,8 +134,8 @@ class AdminTests(TestCase):
     def test_view_manage_user_wrong_perms(self):
         self._login_superuser()
         url = reverse('admin:%s_%s_permissions_manage_user' % self.obj_info,
-            args=[self.obj.pk, self.user.pk])
-        perms = ['change_user'] # This is not self.obj related permission
+                      args=[self.obj.pk, self.user.pk])
+        perms = ['change_user']  # This is not self.obj related permission
         data = {'permissions': perms}
         response = self.client.post(url, data, follow=True)
         self.assertEqual(response.status_code, 200)
@@ -141,19 +144,20 @@ class AdminTests(TestCase):
     def test_view_manage_user(self):
         self._login_superuser()
         url = reverse('admin:%s_%s_permissions_manage_user' % self.obj_info,
-            args=[self.obj.pk, self.user.pk])
+                      args=[self.obj.pk, self.user.pk])
         response = self.client.get(url)
         self.assertEqual(response.status_code, 200)
 
         choices = set([c[0] for c in
-            response.context['form'].fields['permissions'].choices])
+                       response.context['form'].fields['permissions'].choices])
         self.assertEqual(
-            set([ p.codename for p in get_perms_for_model(self.obj)]),
+            set([p.codename for p in get_perms_for_model(self.obj)]),
             choices,
         )
 
         # Add some perms and check if changes were persisted
-        perms = ['change_%s' % self.obj_info[1], 'delete_%s' % self.obj_info[1]]
+        perms = ['change_%s' % self.obj_info[
+            1], 'delete_%s' % self.obj_info[1]]
         data = {'permissions': perms}
         response = self.client.post(url, data, follow=True)
         self.assertEqual(len(response.redirect_chain), 1)
@@ -179,32 +183,32 @@ class AdminTests(TestCase):
     def test_view_manage_group_form(self):
         self._login_superuser()
         url = reverse('admin:%s_%s_permissions' % self.obj_info,
-            args=[self.obj.pk])
+                      args=[self.obj.pk])
         data = {'group': self.group.name, 'submit_manage_group': 'submit'}
         response = self.client.post(url, data, follow=True)
         self.assertEqual(len(response.redirect_chain), 1)
         self.assertEqual(response.redirect_chain[0][1], 302)
         redirect_url = reverse('admin:%s_%s_permissions_manage_group' %
-            self.obj_info, args=[self.obj.pk, self.group.id])
+                               self.obj_info, args=[self.obj.pk, self.group.id])
         self.assertEqual(response.request['PATH_INFO'], redirect_url)
 
     def test_view_manage_negative_group_form(self):
         self._login_superuser()
         url = reverse('admin:%s_%s_permissions' % self.obj_info,
-            args=[self.obj.pk])
+                      args=[self.obj.pk])
         self.group = Group.objects.create(name='neagive_id_group', id=-2010)
         data = {'group': self.group.name, 'submit_manage_group': 'submit'}
         response = self.client.post(url, data, follow=True)
         self.assertEqual(len(response.redirect_chain), 1)
         self.assertEqual(response.redirect_chain[0][1], 302)
         redirect_url = reverse('admin:%s_%s_permissions_manage_group' %
-            self.obj_info, args=[self.obj.pk, self.group.id])
+                               self.obj_info, args=[self.obj.pk, self.group.id])
         self.assertEqual(response.request['PATH_INFO'], redirect_url)
 
     def test_view_manage_group_form_wrong_group(self):
         self._login_superuser()
         url = reverse('admin:%s_%s_permissions' % self.obj_info,
-            args=[self.obj.pk])
+                      args=[self.obj.pk])
         data = {'group': 'wrong-group', 'submit_manage_group': 'submit'}
         response = self.client.post(url, data, follow=True)
         self.assertEqual(len(response.redirect_chain), 0)
@@ -214,7 +218,7 @@ class AdminTests(TestCase):
     def test_view_manage_group_form_wrong_field(self):
         self._login_superuser()
         url = reverse('admin:%s_%s_permissions' % self.obj_info,
-            args=[self.obj.pk])
+                      args=[self.obj.pk])
         data = {'group': '<xss>', 'submit_manage_group': 'submit'}
         response = self.client.post(url, data, follow=True)
         self.assertEqual(len(response.redirect_chain), 0)
@@ -224,7 +228,7 @@ class AdminTests(TestCase):
     def test_view_manage_group_form_empty_group(self):
         self._login_superuser()
         url = reverse('admin:%s_%s_permissions' % self.obj_info,
-            args=[self.obj.pk])
+                      args=[self.obj.pk])
         data = {'group': '', 'submit_manage_group': 'submit'}
         response = self.client.post(url, data, follow=True)
         self.assertEqual(len(response.redirect_chain), 0)
@@ -234,8 +238,8 @@ class AdminTests(TestCase):
     def test_view_manage_group_wrong_perms(self):
         self._login_superuser()
         url = reverse('admin:%s_%s_permissions_manage_group' %
-            self.obj_info, args=[self.obj.pk, self.group.id])
-        perms = ['change_user'] # This is not self.obj related permission
+                      self.obj_info, args=[self.obj.pk, self.group.id])
+        perms = ['change_user']  # This is not self.obj related permission
         data = {'permissions': perms}
         response = self.client.post(url, data, follow=True)
         self.assertEqual(response.status_code, 200)
@@ -244,19 +248,20 @@ class AdminTests(TestCase):
     def test_view_manage_group(self):
         self._login_superuser()
         url = reverse('admin:%s_%s_permissions_manage_group' %
-            self.obj_info, args=[self.obj.pk, self.group.id])
+                      self.obj_info, args=[self.obj.pk, self.group.id])
         response = self.client.get(url)
         self.assertEqual(response.status_code, 200)
 
         choices = set([c[0] for c in
-            response.context['form'].fields['permissions'].choices])
+                       response.context['form'].fields['permissions'].choices])
         self.assertEqual(
-            set([ p.codename for p in get_perms_for_model(self.obj)]),
+            set([p.codename for p in get_perms_for_model(self.obj)]),
             choices,
         )
 
         # Add some perms and check if changes were persisted
-        perms = ['change_%s' % self.obj_info[1], 'delete_%s' % self.obj_info[1]]
+        perms = ['change_%s' % self.obj_info[
+            1], 'delete_%s' % self.obj_info[1]]
         data = {'permissions': perms}
         response = self.client.post(url, data, follow=True)
         self.assertEqual(len(response.redirect_chain), 1)
@@ -284,7 +289,7 @@ if 'django.contrib.admin' not in settings.INSTALLED_APPS:
     # we simpy clean up AdminTests class ...
     # TODO: use @unittest.skipUnless('django.contrib.admin' in settings.INSTALLED_APPS)
     #       if possible (requires Python 2.7, though)
-    AdminTests = type('AdminTests', (TestCase,), {}) # pyflakes:ignore
+    AdminTests = type('AdminTests', (TestCase,), {})  # pyflakes:ignore
 
 
 @skipUnlessTestApp
@@ -309,7 +314,8 @@ class GuardedModelAdminTests(TestCase):
     def test_obj_perms_manage_user_template_attr(self):
         attrs = {'obj_perms_manage_user_template': 'foobar.html'}
         gma = self._get_gma(attrs=attrs)
-        self.assertTrue(gma.get_obj_perms_manage_user_template(), 'foobar.html')
+        self.assertTrue(
+            gma.get_obj_perms_manage_user_template(), 'foobar.html')
 
     def test_obj_perms_manage_user_form_attr(self):
         attrs = {'obj_perms_manage_user_form': forms.Form}
@@ -320,7 +326,7 @@ class GuardedModelAdminTests(TestCase):
         attrs = {'obj_perms_manage_group_template': 'foobar.html'}
         gma = self._get_gma(attrs=attrs)
         self.assertTrue(gma.get_obj_perms_manage_group_template(),
-            'foobar.html')
+                        'foobar.html')
 
     def test_obj_perms_manage_group_form_attr(self):
         attrs = {'obj_perms_manage_group_form': forms.Form}
@@ -337,9 +343,9 @@ class GuardedModelAdminTests(TestCase):
         jane = User.objects.create_user('jane', 'jane@example.com', 'jane')
         ctype = ContentType.objects.get_for_model(User)
         joe_entry = LogEntry.objects.create(user=joe, content_type=ctype,
-            object_id=joe.pk, action_flag=1, change_message='foo')
+                                            object_id=joe.pk, action_flag=1, change_message='foo')
         LogEntry.objects.create(user=jane, content_type=ctype,
-            object_id=jane.pk, action_flag=1, change_message='bar')
+                                object_id=jane.pk, action_flag=1, change_message='bar')
         request = HttpRequest()
         request.user = joe
         qs = gma.get_queryset(request)
@@ -355,14 +361,14 @@ class GuardedModelAdminTests(TestCase):
         jane = User.objects.create_user('jane', 'jane@example.com', 'jane')
         ctype = ContentType.objects.get_for_model(User)
         joe_entry = LogEntry.objects.create(user=joe, content_type=ctype,
-            object_id=joe.pk, action_flag=1, change_message='foo')
+                                            object_id=joe.pk, action_flag=1, change_message='foo')
         jane_entry = LogEntry.objects.create(user=jane, content_type=ctype,
-            object_id=jane.pk, action_flag=1, change_message='bar')
+                                             object_id=jane.pk, action_flag=1, change_message='bar')
         request = HttpRequest()
         request.user = joe
         qs = gma.get_queryset(request)
         self.assertEqual(sorted([e.pk for e in qs]),
-            sorted([joe_entry.pk, jane_entry.pk]))
+                         sorted([joe_entry.pk, jane_entry.pk]))
 
     def test_user_can_access_owned_by_group_objects_only(self):
         attrs = {
@@ -378,12 +384,12 @@ class GuardedModelAdminTests(TestCase):
         jane.groups.add(jane_group)
         ctype = ContentType.objects.get_for_model(User)
         LogEntry.objects.create(user=joe, content_type=ctype,
-            object_id=joe.pk, action_flag=1, change_message='foo')
+                                object_id=joe.pk, action_flag=1, change_message='foo')
         LogEntry.objects.create(user=jane, content_type=ctype,
-            object_id=jane.pk, action_flag=1, change_message='bar')
+                                object_id=jane.pk, action_flag=1, change_message='bar')
         joe_entry_group = LogEntry.objects.create(user=jane, content_type=ctype,
-            object_id=joe.pk, action_flag=1, change_message='foo',
-            group=joe_group)
+                                                  object_id=joe.pk, action_flag=1, change_message='foo',
+                                                  group=joe_group)
         request = HttpRequest()
         request.user = joe
         qs = gma.get_queryset(request)
@@ -403,20 +409,20 @@ class GuardedModelAdminTests(TestCase):
         jane.groups.add(jane_group)
         ctype = ContentType.objects.get_for_model(User)
         LogEntry.objects.create(user=joe, content_type=ctype,
-            object_id=joe.pk, action_flag=1, change_message='foo')
+                                object_id=joe.pk, action_flag=1, change_message='foo')
         LogEntry.objects.create(user=jane, content_type=ctype,
-            object_id=jane.pk, action_flag=1, change_message='bar')
+                                object_id=jane.pk, action_flag=1, change_message='bar')
         LogEntry.objects.create(user=jane, content_type=ctype,
-            object_id=joe.pk, action_flag=1, change_message='foo',
-            group=joe_group)
+                                object_id=joe.pk, action_flag=1, change_message='foo',
+                                group=joe_group)
         LogEntry.objects.create(user=joe, content_type=ctype,
-            object_id=joe.pk, action_flag=1, change_message='foo',
-            group=jane_group)
+                                object_id=joe.pk, action_flag=1, change_message='foo',
+                                group=jane_group)
         request = HttpRequest()
         request.user = joe
         qs = gma.get_queryset(request)
         self.assertEqual(sorted(e.pk for e in qs),
-            sorted(LogEntry.objects.values_list('pk', flat=True)))
+                         sorted(LogEntry.objects.values_list('pk', flat=True)))
 
 
 class GrappelliGuardedModelAdminTests(TestCase):
@@ -443,15 +449,14 @@ class GrappelliGuardedModelAdminTests(TestCase):
     def test_get_obj_perms_manage_template(self):
         gma = self._get_gma()
         self.assertEqual(gma.get_obj_perms_manage_template(),
-            'admin/guardian/contrib/grappelli/obj_perms_manage.html')
+                         'admin/guardian/contrib/grappelli/obj_perms_manage.html')
 
     def test_get_obj_perms_manage_user_template(self):
         gma = self._get_gma()
         self.assertEqual(gma.get_obj_perms_manage_user_template(),
-            'admin/guardian/contrib/grappelli/obj_perms_manage_user.html')
+                         'admin/guardian/contrib/grappelli/obj_perms_manage_user.html')
 
     def test_get_obj_perms_manage_group_template(self):
         gma = self._get_gma()
         self.assertEqual(gma.get_obj_perms_manage_group_template(),
-            'admin/guardian/contrib/grappelli/obj_perms_manage_group.html')
-
+                         'admin/guardian/contrib/grappelli/obj_perms_manage_group.html')
