@@ -1,6 +1,6 @@
 from __future__ import unicode_literals
 from django.test import TestCase
-from guardian.compat import mock
+import mock
 from guardian.managers import UserObjectPermissionManager
 from guardian.managers import GroupObjectPermissionManager
 
@@ -18,4 +18,3 @@ class TestManagers(TestCase):
         manager.assign_perm = mock.Mock()
         manager.assign('perm', 'group', 'object')
         manager.assign_perm.assert_called_once_with('perm', 'group', 'object')
-
