@@ -7,7 +7,7 @@ env = environ.Env()
 
 DEBUG = False
 
-ANONYMOUS_USER_ID = -1
+ANONYMOUS_USER_NAME = "AnonymousUser"
 
 AUTH_USER_MODEL = "testapp.CustomUser"
 GUARDIAN_MONKEY_PATCH = False
@@ -50,3 +50,23 @@ SECRET_KEY = ''.join([random.choice(string.ascii_letters) for x in range(40)])
 # Database specific
 
 DATABASES = {'default': env.db(default="sqlite:///")}
+
+
+TEMPLATES = [
+    {
+        'BACKEND': 'django.template.backends.django.DjangoTemplates',
+        'DIRS': TEMPLATE_DIRS,
+        'APP_DIRS': True,
+        'OPTIONS': {
+            'context_processors': [
+                'django.contrib.auth.context_processors.auth',
+                'django.template.context_processors.debug',
+                'django.template.context_processors.i18n',
+                'django.template.context_processors.media',
+                'django.template.context_processors.static',
+                'django.template.context_processors.tz',
+                'django.contrib.messages.context_processors.messages',
+            ],
+        },
+    },
+]
